import { Logger } from '@adonisjs/logger';
import { H as HttpContext, a as Request, b as Response, Q as QSParserConfig, j as Qs, k as RequestConfig, l as ResponseConfig, R as Router, S as ServerConfig } from '../main-e5b46c83.js';
import { Encryption } from '@adonisjs/encryption';
import { IncomingMessage, ServerResponse } from 'node:http';
import { Application } from '@adonisjs/application';
import { Emitter } from '@adonisjs/events';
import { S as Server } from '../main-29eaaee4.js';
import '@adonisjs/fold';
import '@poppinss/macroable';
import 'node:url';
import 'qs';
import 'http';
import 'stream';
import '@poppinss/middleware';
import '@poppinss/middleware/types';
import 'node:stream';
import 'node:https';

type FactoryParameters$4 = {
    request: Request;
    response: Response;
    logger: Logger;
};
/**
 * HttpContext factory is used to generate Http context class instances for
 * testing
 */
declare class HttpContextFactory {
    #private;
    /**
     * Merge factory params
     */
    merge(params: Partial<FactoryParameters$4>): this;
    /**
     * Create request
     */
    create(): HttpContext;
}

/**
 * QS Parser factory is used to generate the query string
 * parser for testing
 */
declare class QsParserFactory {
    #private;
    /**
     * Merge encryption factory options
     */
    merge(options: Partial<{
        parse: Partial<QSParserConfig['parse']>;
        stringify: Partial<QSParserConfig['stringify']>;
    }>): this;
    /**
     * Create instance of the logger class
     */
    create(): Qs;
}

type FactoryParameters$3 = {
    url: string;
    method: string;
    req: IncomingMessage;
    res: ServerResponse;
    encryption: Encryption;
    config: Partial<RequestConfig>;
};
/**
 * Request factory is used to generate request class instances for
 * testing
 */
declare class RequestFactory {
    #private;
    /**
     * Merge factory params
     */
    merge(params: Partial<FactoryParameters$3>): this;
    /**
     * Create request
     */
    create(): Request;
}

type FactoryParameters$2 = {
    req: IncomingMessage;
    res: ServerResponse;
    encryption: Encryption;
    config: Partial<ResponseConfig>;
    router: Router;
};
/**
 * Response factory is used to generate response class instances for
 * testing
 */
declare class ResponseFactory {
    #private;
    /**
     * Merge factory params
     */
    merge(params: Partial<FactoryParameters$2>): this;
    /**
     * Create response class instance
     */
    create(): Response;
}

type FactoryParameters$1 = {
    app: Application<any>;
    encryption: Encryption;
};
/**
 * Router factory is used to generate router class instances for
 * testing
 */
declare class RouterFactory {
    #private;
    /**
     * Merge factory params
     */
    merge(params: Partial<FactoryParameters$1>): this;
    /**
     * Create router instance
     */
    create(): Router;
}

type FactoryParameters = {
    app: Application<any>;
    logger: Logger;
    encryption: Encryption;
    emitter: Emitter<any>;
    config: Partial<ServerConfig>;
};
/**
 * Server factory is used to generate server class instances for
 * testing
 */
declare class ServerFactory {
    #private;
    /**
     * Merge factory params
     */
    merge(params: Partial<FactoryParameters>): this;
    /**
     * Create server instance
     */
    create(): Server;
}

export { HttpContextFactory, QsParserFactory, RequestFactory, ResponseFactory, RouterFactory, ServerFactory };
