import { Logger } from '@adonisjs/logger';
import { Emitter } from '@adonisjs/events';
import { Encryption } from '@adonisjs/encryption';
import { Server as Server$2 } from 'node:https';
import { Application } from '@adonisjs/application';
import { ContainerResolver } from '@adonisjs/fold';
import { Server as Server$1, IncomingMessage, ServerResponse } from 'node:http';
import { S as ServerConfig, M as MiddlewareAsClass, T as TestingMiddlewarePipeline, L as LazyImport, E as ErrorHandlerAsAClass, R as Router, a as Request, b as Response, H as HttpContext } from './main-e5b46c83.js';

/**
 * The HTTP server implementation to handle incoming requests and respond using the
 * registered routes.
 */
declare class Server {
    #private;
    /**
     * Know if async local storage is enabled or not.
     */
    get usingAsyncLocalStorage(): boolean;
    constructor(app: Application<any>, encryption: Encryption, emitter: Emitter<any>, logger: Logger, config: ServerConfig);
    /**
     * Creates a pipeline of middleware.
     */
    pipeline(middleware: MiddlewareAsClass[]): TestingMiddlewarePipeline;
    /**
     * Define an array of middleware to use on all the incoming HTTP request.
     * Calling this method multiple times pushes to the existing list
     * of middleware
     */
    use(middleware: LazyImport<MiddlewareAsClass>[]): this;
    /**
     * Register a custom error handler for HTTP requests.
     * All errors will be reported to this method
     */
    errorHandler(handler: LazyImport<ErrorHandlerAsAClass>): this;
    /**
     * Boot the server. Calling this method performs the following actions.
     *
     * - Register routes with the store.
     * - Resolve and construct the error handler.
     */
    boot(): Promise<void>;
    /**
     * Set the HTTP server instance used to listen for requests.
     */
    setNodeServer(server: Server$1 | Server$2): void;
    /**
     * Returns reference to the underlying HTTP server
     * in use
     */
    getNodeServer(): Server$1<typeof IncomingMessage, typeof ServerResponse> | Server$2<typeof IncomingMessage, typeof ServerResponse> | undefined;
    /**
     * Returns reference to the router instance used
     * by the server.
     */
    getRouter(): Router;
    /**
     * Creates an instance of the [[Request]] class
     */
    createRequest(req: IncomingMessage, res: ServerResponse): Request;
    /**
     * Creates an instance of the [[Response]] class
     */
    createResponse(req: IncomingMessage, res: ServerResponse): Response;
    /**
     * Creates an instance of the [[HttpContext]] class
     */
    createHttpContext(request: Request, response: Response, resolver: ContainerResolver<any>): HttpContext;
    /**
     * Handle request
     */
    handle(req: IncomingMessage, res: ServerResponse): Promise<any>;
}

export { Server as S };
